# CLI home.nix
{ config, lib, pkgs, inputs, user, ... }:
{
  home.shellAliases = {
    wget = "wget --hsts-file=${config.xdg.configHome}/wget-hsts";
    doas = "sudo";
    ls = "ls -l";
    ll = "ls -alF";
    trim = "awk '{\$1=\$1;print}'";
  };
  home.sessionPath = [
    "${config.home.homeDirectory}/.local/share/go/bin"
  ];
  xdg.configFile = {
    "cava" = {
      source = ./dots/cava;
      target = "cava";
      recursive = true;
    };
  };
  xdg = {
    userDirs = {
      enable = true;
      createDirectories = true;
      desktop = "${config.home.homeDirectory}/Desktop";
      documents = "${config.home.homeDirectory}/Documents";
      download = "${config.home.homeDirectory}/Downloads";
      music = "${config.home.homeDirectory}/Music";
      pictures = "${config.home.homeDirectory}/Pictures";
      publicShare = "${config.home.homeDirectory}/Public";
      templates = "${config.home.homeDirectory}/Templates";
      videos = "${config.home.homeDirectory}/Videos";
    };
  };
  programs = {
    go = {
      goPath = "${config.xdg.dataHome}/go";
    };
    neovim = {
      extraConfig = ''
                    let g:limelight_conceal_ctermfg = 'block'
      '';
      plugins = with pkgs.vimPlugins; [
        dracula-nvim
        goyo-vim
        limelight-vim
        twilight-nvim
        vim-nix
        vimwiki
        zen-mode-nvim
      ];
    };
    yt-dlp = {
      extraConfig = ''
                    --update
      '';
      settings = {
        embed-thumbnail = true;
        embed-subs = true;
        sub-langs = "all";
        downloader = "aria2c";
        downloader-args = "aria2c:'-c -x8 -s8 -k1M'";
      };
    };
  };
}
