# Hosts default.nix
{ lib, inputs, system, home-manager, user, ... }:
{
  buckwheat = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../nixos/all.nix
      ../nixos/cli.nix
      ../nixos/chat.nix
      ../nixos/wayland.nix
      ../nixos/gaming.nix
      ../nixos/office.nix
      ./buckwheat/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user.name} = {
          imports = [
            ../home-manager/all.nix
            ../home-manager/cli.nix
            ../home-manager/chat.nix
            ../home-manager/wayland.nix
            ./buckwheat/home.nix
          ];
        };
      }
    ];
  };
  fireweed = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../nixos/all.nix
      ../nixos/cli.nix
      ../nixos/xorg.nix
      ../nixos/office.nix
      ../nixos/pentest.nix
      ./fireweed/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user.name} = {
          imports = [
            ../home-manager/all.nix
            ../home-manager/cli.nix
            ../home-manager/xorg.nix
            ./fireweed/home.nix
          ];
        };
      }
    ];
  };
  vm = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../nixos/all.nix
      ../nixos/cli.nix
      ./vm/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user.name} = {
          imports = [
            ../home-manager/all.nix
            ../home-manager/cli.nix
            ./vm/home.nix
          ];
        };
      }
    ];
  };
}
