# Fireweed hardware-configuration.nix
{ config, lib, pkgs, modulesPath, ... }:

{
  imports =
    [ (modulesPath + "/installer/scan/not-detected.nix")
    ];

  boot.initrd.availableKernelModules = [ "xhci_pci" "ahci" "nvme" "uas" "usb_storage" "usbhid" "sd_mod" ];
  boot.initrd.kernelModules = [ "amdgpu" ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.kernelPackages = pkgs.linuxPackages_latest;
  boot.extraModulePackages = [ ];

  fileSystems."/" = {
    device = "/dev/disk/by-uuid/c9833e85-0ea9-45a9-b65d-039c8c4f71f3";
    fsType = "ext4";
  };

  fileSystems."/boot/efi" = {
    device = "/dev/disk/by-uuid/5E0D-1487";
    fsType = "vfat";
  };

  fileSystems."/mnt/daily" = {
    device = "/dev/disk/by-uuid/bfdd61f6-2d26-4140-94ac-e60c21636dde";
    fsType = "ext4";
  };

  fileSystems."/mnt/weekly" = {
    device = "/dev/disk/by-uuid/56f7fd65-bf5d-4ce6-830a-ea8fbf6610af";
    fsType = "ext4";
  };

  fileSystems."/mnt/videos" = {
    device = "/dev/disk/by-uuid/e1f9cf9a-4147-4849-83e2-4baa342b6400";
    fsType = "ext4";
  };

  #fileSystems."/media" =
  #  { device = "/mnt/videos";
  #    fsType = "none";
  #    options = [ "bind" ];
  #  };

  swapDevices = [ ];

  # Enables DHCP on each ethernet and wireless interface. In case of scripted networking
  # (the default) this is the recommended approach. When using systemd-networkd it's
  # still possible to use this option, but it's recommended to use it in conjunction
  # with explicit per-interface declarations with `networking.interfaces.<interface>.useDHCP`.
  networking.useDHCP = lib.mkDefault true;
  # networking.interfaces.enp3s0.useDHCP = lib.mkDefault true;
  # networking.interfaces.virbr0.useDHCP = lib.mkDefault true;
  # networking.interfaces.virbr1.useDHCP = lib.mkDefault true;
  # networking.interfaces.virbr2.useDHCP = lib.mkDefault true;
  # networking.interfaces.virbr3.useDHCP = lib.mkDefault true;
  # networking.interfaces.wg-mullvad.useDHCP = lib.mkDefault true;
  # networking.interfaces.wlo1.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  powerManagement.cpuFreqGovernor = lib.mkDefault "powersave";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
